import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:universal_io/io.dart';

enum FormFactorType { SmallScreen, MediumScreen, LargeScreen, ExtraLargeScreen }

class ScreenSizes {
  static const int small = 300;
  static const int medium = 600;
  static const int large = 900;
}

// Get the device form factor as best we can.
class FormFactorTypeHelper {
  static FormFactorType get(BuildContext context) {
    double width = MediaQuery.of(context).size.width;
    if (width <= ScreenSizes.small) return FormFactorType.SmallScreen;
    if (width <= ScreenSizes.medium) return FormFactorType.MediumScreen;
    if (width <= ScreenSizes.large) return FormFactorType.LargeScreen;
    return FormFactorType.ExtraLargeScreen;
  }
}

class DeviceOS {
  static bool isIOS = defaultTargetPlatform == TargetPlatform.iOS;
  static bool isAndroid = defaultTargetPlatform == TargetPlatform.android;

  static bool get isMobile => isAndroid || isIOS;
}

class DevicePlatform {
  // Syntax sugar, proxy the UniversalPlatform methods so our views can reference a single class
  static bool isIOS = Platform.isIOS;
  static bool isAndroid = Platform.isAndroid;

  // Higher level device class abstractions (more syntax sugar for the views)
  static bool isWeb = kIsWeb;
  static bool get isMobile => isAndroid || isIOS;
  static bool get isMobileOrWeb => isMobile || isWeb;
}

class DeviceScreen {
  // Shortcuts for various mobile device types
  static bool isSmallScreen(BuildContext context) =>
      FormFactorTypeHelper.get(context) == FormFactorType.SmallScreen;
  static bool isMediumScreen(BuildContext context) =>
      FormFactorTypeHelper.get(context) == FormFactorType.MediumScreen;
  static bool isPhone(BuildContext context) =>
      isSmallScreen(context) || isMediumScreen(context);

  static bool isLargeScreen(BuildContext context) =>
      FormFactorTypeHelper.get(context) == FormFactorType.LargeScreen;
  static bool isExtraLargeScreen(BuildContext context) =>
      FormFactorTypeHelper.get(context) == FormFactorType.ExtraLargeScreen;

  static bool isWideScreen(BuildContext context) =>
      isLargeScreen(context) || isExtraLargeScreen(context);
}
