import 'dart:convert';

import 'package:dio/dio.dart';
import 'package:flutter/foundation.dart';

class LoggingInterceptor extends Interceptor {
  @override
  Future onError(DioError err, ErrorInterceptorHandler handler) async {
    debugPrint("""ERROR:
    URL: ${err.requestOptions.uri}\n
    Method: ${err.requestOptions.method} 
    Headers: ${jsonEncode(err.response!.headers.map)}
    StatusCode: ${err.response!.statusCode}
    Data: ${jsonEncode(err.response!.data)}
    <-- END HTTP
        """, wrapWidth: 1024);
    return super.onError(err, handler);
  }

  @override
  Future onRequest(
      RequestOptions options, RequestInterceptorHandler handler) async {
    debugPrint("""REQUEST:
    ${cURLRepresentation(options)}
    """, wrapWidth: 1024);
    return super.onRequest(options, handler);
  }

  @override
  Future onResponse(
      Response response, ResponseInterceptorHandler handler) async {
    debugPrint("""RESPONSE:
    URL: ${response.requestOptions.uri}
    Method: ${response.requestOptions.method}
    Headers: ${jsonEncode(response.requestOptions.headers)}
    Data: ${jsonEncode(response.data)}
        """, wrapWidth: 1024);
    return super.onResponse(response, handler);
  }

  String cURLRepresentation(RequestOptions options) {
    List<String> components = ["\$ curl -i"];
    if (options.method.toUpperCase() == "GET") {
      components.add("-X ${options.method}");
    }

    options.headers.forEach((k, v) {
      if (k != "Cookie") {
        components.add("-H \"$k: $v\"");
      }
    });

    var data = jsonEncode(options.data);
    data = data.replaceAll('\"', '\\\"');
    components.add("-d \"$data\"");

    components.add("\"${options.uri.toString()}\"");

    return components.join('\\\n\t');
  }
}
