import 'package:dcoupon_sdk_flutter_package/src/config_reader.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/device_info.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/helpers/authorization_helper.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/constants.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/enum_helper.dart';

const String VERSION = "v4";

const String API_PATH_NAME = '/users';

const Map<String, String> URLS_BY_ENVIRONMENT = {
  'dev': 'https://services-dev.dcoupon.com',
  'dcoupon.eu': 'https://services.dcoupon.eu',
  'dcoupon-latam.com': 'https://services-latam.dcoupon.com',
  'dcoupon.com': 'https://services.dcoupon.com'
};

class UsersApiHelper {
  static Map<String, dynamic> buildHeaders({
    bool userAuthentication = true,
  }) {
    var headers = <String, dynamic>{};

    final currentDateFormatted = AuthorizationHelper.getCurrentDateFormatted();
    headers[Constants.HEADER_AUTH_METHOD] =
        EnumHelper.enumToString(AuthMethod.SIGNATURE);
    headers[Constants.HEADER_AUTH_TIMESTAMP] = currentDateFormatted;
    headers[Constants.HEADER_AUTH_APIKEY] = ConfigReader.clientApiToken;
    headers[Constants.HEADER_AUTH_SIGNATURE] =
        AuthorizationHelper.getAuthSignature(currentDateFormatted);
    if (userAuthentication) {
      headers[Constants.HEADER_USER_JWT] = ConfigReader.userJwt;
    }

    return headers;
  }

  static String getEndpointUrl() {
    if (DevicePlatform.isWeb && ConfigReader.webOrigin != null) {
      return ConfigReader.webOrigin!;
    }
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]!;
  }

  static String getUserDataUrl() {
    const methodPath = '/$VERSION/data';
    return getEndpointUrl() + API_PATH_NAME + methodPath;
  }

  static String updateUserDataUrl() {
    const methodPath = '/$VERSION/data';
    return getEndpointUrl() + API_PATH_NAME + methodPath;
  }

  static String unregisterUserUrl() {
    const methodPath = '/$VERSION/unregisterUser';
    return getEndpointUrl() + API_PATH_NAME + methodPath;
  }

  static String getLoyaltyAffiliatesUrl() {
    final methodPath = '/$VERSION/loyalty/affiliates';
    return getEndpointUrl() + API_PATH_NAME + methodPath;
  }

  static String addOrUpdateLoyaltyCardUrl() {
    const methodPath = '/$VERSION/loyalty/card';
    return getEndpointUrl() + API_PATH_NAME + methodPath;
  }

  static String deleteLoyaltyCardUrl() {
    const methodPath = '/$VERSION/loyalty/card';
    return getEndpointUrl() + API_PATH_NAME + methodPath;
  }

  static String getUserRedemptionSummaryUrl() {
    const methodPath = '/$VERSION/redemption/summary';
    return getEndpointUrl() + API_PATH_NAME + methodPath;
  }

  static String getUserRedemptionHistoryUrl() {
    const methodPath = '/$VERSION/redemption/history';
    return getEndpointUrl() + API_PATH_NAME + methodPath;
  }

  static String getRedemptionDetail(String redemptionId) {
    final methodPath = '/$VERSION/redemption/detail/$redemptionId';
    return getEndpointUrl() + API_PATH_NAME + methodPath;
  }
}
