import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dartz/dartz.dart';

import 'package:dcoupon_sdk_flutter_package/src/data/datasources/coupon_remote_data_sources.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/coupon_repository.dart';

class CouponRepositoryImpl implements CouponRepository {
  final CouponRemoteDataSource remoteDataSource;

  CouponRepositoryImpl({
    required this.remoteDataSource,
  });

  @override
  Future<Either<Failure, dynamic>> getCoupons({
    int? offset,
    int? limit,
    String? sortBy,
    List<String>? companyTokens,
    List<String>? retailerTokens,
  }) async {
    return await remoteDataSource.getCoupons(
      offset: offset,
      limit: limit,
      sortBy: sortBy,
      companyTokens: companyTokens,
      retailerTokens: retailerTokens,
    );
  }

  @override
  Future<Either<Failure, dynamic>> activateCoupon({
    required String couponId,
  }) async {
    return await remoteDataSource.activateCoupon(
      couponId: couponId,
    );
  }

  @override
  Future<Either<Failure, dynamic>> createUserCoupons({
    required List<String> promotionTokens,
    String? latitude,
    String? longitude,
    String? saveMethod,
    String? utmSource,
    String? transId,
    String? crmId,
    required String publisherToken,
  }) async {
    return await remoteDataSource.createUserCoupons(
      promotionTokens: promotionTokens,
      latitude: latitude,
      longitude: longitude,
      saveMethod: saveMethod,
      utmSource: utmSource,
      transId: transId,
      crmId: crmId,
      publisherToken: publisherToken,
    );
  }

  @override
  Future<Either<Failure, dynamic>> deactivateCoupon({
    required String couponId,
  }) async {
    return await remoteDataSource.deactivateCoupon(
      couponId: couponId,
    );
  }

  @override
  Future<Either<Failure, dynamic>> getCouponDetail({
    required String couponId,
  }) async {
    return await remoteDataSource.getCouponDetail(
      couponId: couponId,
    );
  }

  @override
  Future<Either<Failure, dynamic>> getUserCouponsCompanies() async {
    return await remoteDataSource.getUserCouponsCompanies();
  }

  @override
  Future<Either<Failure, dynamic>> getUserCouponsRetailers() async {
    return await remoteDataSource.getUserCouponsRetailers();
  }
}
