import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/datasources/redemption_remote_data_source.dart';

import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/redemption_repository.dart';

class RedemptionRepositoryImpl implements RedemptionRepository {
  final RedemptionRemoteDataSource remoteDataSource;

  RedemptionRepositoryImpl({
    required this.remoteDataSource,
  });

  @override
  Future<Either<Failure, dynamic>> getUserRedemptionSummary({
    required String groupBy,
    String? startDate,
    String? endDate,
    required int gmtTimeZoneOffset,
  }) async {
    return await remoteDataSource.getUserRedemptionSummary(
      groupBy: groupBy,
      startDate: startDate,
      endDate: endDate,
      gmtTimeZoneOffset: gmtTimeZoneOffset,
    );
  }

  @override
  Future<Either<Failure, dynamic>> getUserRedemptionHistory({
    int? limit,
    int? offset,
    String? startDate,
    String? endDate,
    required int gmtTimeZoneOffset,
  }) async {
    return await remoteDataSource.getUserRedemptionHistory(
      limit: limit,
      offset: offset,
      startDate: startDate,
      endDate: endDate,
      gmtTimeZoneOffset: gmtTimeZoneOffset,
    );
  }

  @override
  Future<Either<Failure, dynamic>> getRedemptionDetail({
    required String redemptionId,
    required int gmtTimeZoneOffset,
  }) async {
    return await remoteDataSource.getRedemptionDetail(
      redemptionId: redemptionId,
      gmtTimeZoneOffset: gmtTimeZoneOffset,
    );
  }

  @override
  Future<Either<Failure, dynamic>> getRedemptionCode() async {
    return await remoteDataSource.getRedemptionCode();
  }
}
