import 'dart:async';

import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/config_reader.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/exceptions.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/datasources/user_remote_data_source.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/user_repository.dart';

class UserRepositoryImpl implements UserRepository {
  final UserRemoteDataSource remoteDataSource;

  UserRepositoryImpl({
    required this.remoteDataSource,
  });

  @override
  Future<Either<Failure, String>> logIn({
    required String externalId,
    String? referralCode,
  }) async {
    try {
      final failureOrUserLoginResponse = await remoteDataSource.logIn(
        externalId: externalId,
        referralCode: referralCode,
      );

      return failureOrUserLoginResponse;
    } on ServerException {
      return Left(ServerFailure());
    }
  }

  @override
  Future<Either<Failure, void>> logOut() async {
    try {
      ConfigReader.setUserJwt(null);
      return Right(null);
    } on CacheException {
      return Left(CacheFailure());
    }
  }

  @override
  Future<Either<Failure, dynamic>> getUserData() async {
    return await remoteDataSource.getUserData();
  }

  @override
  Future<Either<Failure, dynamic>> updateUserData({
    required String alias,
    required String gender,
    required String birthdate,
  }) async {
    return await remoteDataSource.updateUserData(
      alias: alias,
      gender: gender,
      birthdate: birthdate,
    );
  }

  @override
  Future<Either<Failure, dynamic>> unregisterUser() async {
    return await remoteDataSource.unregisterUser();
  }
}
