import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/usecases/usecase.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/coupon_repository.dart';
import 'package:equatable/equatable.dart';

class CouponCreateUserCoupons
    implements UseCase<dynamic, CouponCreateUserCouponsParams> {
  final CouponRepository repository;

  CouponCreateUserCoupons(this.repository);

  @override
  Future<Either<Failure, dynamic>> call(
      CouponCreateUserCouponsParams params) async {
    return await repository.createUserCoupons(
      promotionTokens: params.promotionTokens,
      latitude: params.latitude,
      longitude: params.longitude,
      saveMethod: params.saveMethod,
      utmSource: params.utmSource,
      transId: params.transId,
      crmId: params.crmId,
      publisherToken: params.publisherToken,
    );
  }
}

class CouponCreateUserCouponsParams extends Equatable {
  final List<String> promotionTokens;
  final String? latitude;
  final String? longitude;
  final String? saveMethod;
  final String? utmSource;
  final String? transId;
  final String? crmId;
  final String publisherToken;

  CouponCreateUserCouponsParams({
    required this.promotionTokens,
    this.latitude,
    this.longitude,
    this.saveMethod,
    this.utmSource,
    this.transId,
    this.crmId,
    required this.publisherToken,
  });

  @override
  List<Object?> get props => [
        promotionTokens,
        latitude,
        longitude,
        saveMethod,
        utmSource,
        transId,
        crmId,
        publisherToken,
      ];
}
