import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/usecases/usecase.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/coupon_repository.dart';
import 'package:equatable/equatable.dart';

class CouponDeactivateCoupon
    implements UseCase<dynamic, CouponDeactivateCouponParams> {
  final CouponRepository repository;

  CouponDeactivateCoupon(this.repository);

  @override
  Future<Either<Failure, dynamic>> call(
      CouponDeactivateCouponParams params) async {
    return await repository.deactivateCoupon(
      couponId: params.couponId,
    );
  }
}

class CouponDeactivateCouponParams extends Equatable {
  final String couponId;

  CouponDeactivateCouponParams({
    required this.couponId,
  });

  @override
  List<Object?> get props => [
        couponId,
      ];
}
