import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/usecases/usecase.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/promotion_repository.dart';
import 'package:equatable/equatable.dart';

class PromotionGetCategories
    implements UseCase<dynamic, PromotionGetCategoriesParams> {
  final PromotionRepository repository;

  PromotionGetCategories(this.repository);

  @override
  Future<Either<Failure, dynamic>> call(
      PromotionGetCategoriesParams params) async {
    return await repository.getCategories(
      lang: params.lang,
      publisherToken: params.publisherToken,
    );
  }
}

class PromotionGetCategoriesParams extends Equatable {
  final String lang;
  final String publisherToken;

  PromotionGetCategoriesParams({
    required this.lang,
    required this.publisherToken,
  });

  @override
  List<Object?> get props => [
        lang,
        publisherToken,
      ];
}
