import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/usecases/usecase.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/promotion_repository.dart';
import 'package:equatable/equatable.dart';

class PromotionGetCompanies
    implements UseCase<dynamic, PromotionGetCompaniesParams> {
  final PromotionRepository repository;

  PromotionGetCompanies(this.repository);

  @override
  Future<Either<Failure, dynamic>> call(
      PromotionGetCompaniesParams params) async {
    return await repository.getCompanies(
      start: params.start,
      limit: params.limit,
      publisherToken: params.publisherToken,
    );
  }
}

class PromotionGetCompaniesParams extends Equatable {
  final int? start;
  final int? limit;
  final String publisherToken;

  PromotionGetCompaniesParams({
    this.start,
    this.limit,
    required this.publisherToken,
  });

  @override
  List<Object?> get props => [
        start,
        limit,
        publisherToken,
      ];
}
