import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/usecases/usecase.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/redemption_repository.dart';
import 'package:equatable/equatable.dart';

class RedemptionGetUserRedemptionHistory
    implements UseCase<dynamic, RedemptionGetUserRedemptionHistoryParams> {
  final RedemptionRepository repository;

  RedemptionGetUserRedemptionHistory(this.repository);

  @override
  Future<Either<Failure, dynamic>> call(
      RedemptionGetUserRedemptionHistoryParams params) async {
    return await repository.getUserRedemptionHistory(
      limit: params.limit,
      offset: params.offset,
      startDate: params.startDate,
      endDate: params.endDate,
      gmtTimeZoneOffset: params.gmtTimeZoneOffset,
    );
  }
}

class RedemptionGetUserRedemptionHistoryParams extends Equatable {
  final int? limit;
  final int? offset;
  final String? startDate;
  final String? endDate;
  final int gmtTimeZoneOffset;

  RedemptionGetUserRedemptionHistoryParams({
    this.limit,
    this.offset,
    this.startDate,
    this.endDate,
    required this.gmtTimeZoneOffset,
  });

  @override
  List<Object?> get props => [
        limit,
        offset,
        startDate,
        endDate,
        gmtTimeZoneOffset,
      ];
}
