import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/usecases/usecase.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/redemption_repository.dart';

import 'package:equatable/equatable.dart';

class RedemptionGetUserRedemptionSummary
    implements UseCase<dynamic, RedemptionGetUserRedemptionSummaryParams> {
  final RedemptionRepository repository;

  RedemptionGetUserRedemptionSummary(this.repository);

  @override
  Future<Either<Failure, dynamic>> call(
      RedemptionGetUserRedemptionSummaryParams params) async {
    return await repository.getUserRedemptionSummary(
      groupBy: params.groupBy,
      startDate: params.startDate,
      endDate: params.endDate,
      gmtTimeZoneOffset: params.gmtTimeZoneOffset,
    );
  }
}

class RedemptionGetUserRedemptionSummaryParams extends Equatable {
  final String groupBy;
  final String? startDate;
  final String? endDate;
  final int gmtTimeZoneOffset;

  RedemptionGetUserRedemptionSummaryParams({
    required this.groupBy,
    this.startDate,
    this.endDate,
    required this.gmtTimeZoneOffset,
  });

  @override
  List<Object?> get props => [
        groupBy,
        startDate,
        endDate,
        gmtTimeZoneOffset,
      ];
}
