import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/usecases/usecase.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/user_repository.dart';

import 'package:equatable/equatable.dart';

class UserLogIn implements UseCase<String, UserLogInParams> {
  final UserRepository repository;

  UserLogIn(this.repository);

  @override
  Future<Either<Failure, String>> call(
      UserLogInParams params) async {
    return await repository.logIn(
      externalId: params.externalId,
      referralCode: params.referralCode,
    );
  }
}

class UserLogInParams extends Equatable {
  final String externalId;
  final String? referralCode;

  UserLogInParams({
    required this.externalId,
    this.referralCode,
  });

  @override
  List<Object?> get props => [
        externalId,
        referralCode,
      ];
}
