import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/usecases/usecase.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/user_repository.dart';
import 'package:equatable/equatable.dart';

class UserUpdateUserData implements UseCase<dynamic, UserUpdateUserDataParams> {
  final UserRepository? repository;

  UserUpdateUserData(this.repository);

  @override
  Future<Either<Failure, dynamic>> call(UserUpdateUserDataParams params) async {
    return await repository!.updateUserData(
      alias: params.alias,
      gender: params.gender,
      birthdate: params.birthdate,
    );
  }
}

class UserUpdateUserDataParams extends Equatable {
  final String alias;
  final String gender;
  final String birthdate;

  UserUpdateUserDataParams({
    required this.alias,
    required this.gender,
    required this.birthdate,
  });

  @override
  List<Object?> get props => [
        alias,
        gender,
        birthdate,
      ];
}
